var querystring = require("querystring");
var async = require("async");
var qs = querystring.parse(window.location.search.slice(1));
var info = { projectId: qs.project };
var socket = SupClient.connect(info.projectId);
socket.on("welcome", onWelcome);
function onWelcome(clientId, config) {
    SupClient.fetch("/systems/" + config.systemId + "/plugins.json", "json", function (err, pluginsInfo) {
        if (err) {
            console.error(err);
            return;
        }
        async.each(pluginsInfo.list, function (pluginName) {
            // pluginName = vendorname/shortpluginname   
            var pluginDocUrl = "/systems/" + config.systemId + "/plugins/" + pluginName + "/docs";
            var pluginData = pluginName.split("/");
            var vendorName = pluginData[0];
            var shortPluginName = pluginData[1];
            SupClient.fetch(pluginDocUrl, "text", function (err, a) {
                if (err != null)
                    return;
                buildVendorSection(vendorName);
                buildPluginLink(vendorName, shortPluginName, pluginDocUrl);
                SupClient.fetch(pluginDocUrl + "/manifest.json", "json", function (err, manifest) {
                    buildVendorSection(vendorName, manifest);
                    buildPluginLink(vendorName, shortPluginName, null, manifest);
                });
            });
        }); // end loop plugins
    });
}
var navListElt = document.querySelector("nav ul");
function buildVendorSection(vendorName, manifest) {
    var vendorLiElt = document.getElementById(vendorName);
    var vendorUlElt;
    var vendorSpanElt;
    if (vendorLiElt == null) {
        vendorLiElt = document.createElement("li"); // vendor li
        vendorLiElt.id = vendorName;
        // vendor name
        var vendorSpanElt_1 = document.createElement("span");
        vendorSpanElt_1.id = vendorName + "-name";
        vendorSpanElt_1.textContent = vendorName;
        vendorLiElt.appendChild(vendorSpanElt_1);
        // vendor's plugin list
        vendorUlElt = document.createElement("ul");
        vendorUlElt.id = vendorName + "-plugins";
        vendorLiElt.appendChild(vendorUlElt);
        navListElt.appendChild(vendorLiElt);
    }
    if (manifest != null) {
        if (vendorSpanElt == null)
            vendorSpanElt = document.getElementById(vendorName + "-name");
        ;
        if (manifest.vendorUrl != null) {
            var vendorAElt = document.querySelector("#" + vendorName + " span a");
            if (vendorAElt == null) {
                vendorAElt = document.createElement("a");
                vendorAElt.target = "_blank";
                vendorSpanElt.textContent = null;
                vendorSpanElt.appendChild(vendorAElt);
            }
            vendorAElt.href = manifest.vendorUrl;
            vendorAElt.title = "Go to " + manifest.vendorUrl;
            if (manifest.vendorName != null)
                vendorName = manifest.vendorName;
            vendorAElt.textContent = vendorName;
        }
        else if (manifest.vendorName != null) {
            vendorSpanElt.textContent = manifest.vendorName;
        }
    }
}
function buildPluginLink(vendorName, pluginName, pluginDocUrl, manifest) {
    var vendorUlElt = document.getElementById(vendorName + "-plugins");
    var pluginLiElt = document.getElementById(vendorName + "-" + pluginName);
    if (pluginLiElt == null) {
        pluginLiElt = document.createElement("li");
        pluginLiElt.id = vendorName + "-" + pluginName;
        vendorUlElt.appendChild(pluginLiElt);
        var anchorElt = document.createElement("a"); // plugin link
        pluginLiElt.appendChild(anchorElt);
        anchorElt.id = "link-" + vendorName + pluginName;
        anchorElt.docRelPath = pluginDocUrl;
        anchorElt.href = "#" + vendorName + pluginName;
        anchorElt.textContent = pluginName;
    }
    if (manifest != null && manifest.pluginName != null) {
        var anchorElt = pluginLiElt.firstChild;
        anchorElt.textContent = manifest.pluginName;
    }
    selectFirstLink();
}
// handle clicks on the "links"
var iframe = document.querySelector("iframe");
navListElt.addEventListener("click", function (event) {
    // don't do anything if the element isn't a plugin link
    if (event.target.docRelPath === undefined)
        return;
    var activeElt = navListElt.querySelector("li a.active");
    if (activeElt != null)
        activeElt.classList.remove("active");
    event.target.classList.add("active");
    iframe.src = event.target.docRelPath;
});
// select the first item in the list
function selectFirstLink() {
    var a = navListElt.querySelector("li li a");
    if (a.className.indexOf("active") === -1) {
        a.classList.add("active");
        iframe.src = a.docRelPath;
    }
}
;
